@@ -1,3 +1,4 @@
+import os
 import shutil
 from pathlib import Path
 from tempfile import TemporaryDirectory
@@ -385,11 +386,37 @@ def test_main_custom_template_dir(capsys: CaptureFixture) -> None:
 
 @freeze_time('2019-07-26')
 def test_pyproject():
+    current_dir = os.getcwd()
     with TemporaryDirectory() as output_dir:
         output_dir = Path(output_dir)
-        pyproject_toml = Path(DATA_PATH) / "project" / "pyproject.toml"
-        shutil.copy(pyproject_toml, output_dir)
         output_file: Path = output_dir / 'output.py'
+        pyproject_toml_path = Path(DATA_PATH) / "project" / "pyproject.toml"
+        pyproject_toml = (
+            pyproject_toml_path.read_text()
+            .replace('INPUT_PATH', str(OPEN_API_DATA_PATH / 'api.yaml'))
+            .replace('OUTPUT_PATH', str(output_file))
+        )
+        (output_dir / 'pyproject.toml').write_text(pyproject_toml)
+
+        os.chdir(output_dir)
+        return_code: Exit = main([])
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (EXPECTED_MAIN_PATH / 'pyproject' / 'output.py').read_text()
+        )
+    os.chdir(current_dir)
+    with pytest.raises(SystemExit):
+        main()
+
+
+@freeze_time('2019-07-26')
+def test_pyproject_not_found():
+    current_dir = os.getcwd()
+    with TemporaryDirectory() as output_dir:
+        output_dir = Path(output_dir)
+        output_file: Path = output_dir / 'output.py'
+        os.chdir(output_dir)
         return_code: Exit = main(
             [
                 '--input',
@@ -401,11 +428,25 @@ def test_pyproject():
         assert return_code == Exit.OK
         assert (
             output_file.read_text()
-            == (EXPECTED_MAIN_PATH / 'pyproject' / 'output.py').read_text()
+            == (EXPECTED_MAIN_PATH / 'pyproject_not_found' / 'output.py').read_text()
         )
+    os.chdir(current_dir)
 
-    with pytest.raises(SystemExit):
-        main()
+
+@freeze_time('2019-07-26')
+def test_stdin(monkeypatch):
+    with TemporaryDirectory() as output_dir:
+        output_dir = Path(output_dir)
+        output_file: Path = output_dir / 'output.py'
+        monkeypatch.setattr('sys.stdin', (OPEN_API_DATA_PATH / 'api.yaml').open())
+        return_code: Exit = main(
+            ['--output', str(output_file),]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (EXPECTED_MAIN_PATH / 'stdin' / 'output.py').read_text()
+        )
 
 
 @freeze_time('2019-07-26')
@@ -604,3 +645,28 @@ def test_main_with_snake_case_field():
 
     with pytest.raises(SystemExit):
         main()
+
+
+@freeze_time('2019-07-26')
+def test_main_with_strip_default_none():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(OPEN_API_DATA_PATH / 'api.yaml'),
+                '--output',
+                str(output_file),
+                '--strip-default-none',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (
+                EXPECTED_MAIN_PATH / 'main_with_strip_default_none' / 'output.py'
+            ).read_text()
+        )
+
+    with pytest.raises(SystemExit):
+        main()
